6f6f02f352
Intentionally trigger sw exceptions to verify GPU can handle abnormal scenarios Change-Id: Ie80aa21883a912834ce6d917ecbb21ff6b3145f5 Signed-off-by: Chris Freehill <cfreehil@amd.com>
77 lines
3.1 KiB
Common Lisp
77 lines
3.1 KiB
Common Lisp
/*
|
|
* =============================================================================
|
|
* ROC Runtime Conformance Release License
|
|
* =============================================================================
|
|
* The University of Illinois/NCSA
|
|
* Open Source License (NCSA)
|
|
*
|
|
* Copyright (c) 2024, Advanced Micro Devices, Inc.
|
|
* All rights reserved.
|
|
*
|
|
* Developed by:
|
|
*
|
|
* AMD Research and AMD ROC Software Development
|
|
*
|
|
* Advanced Micro Devices, Inc.
|
|
*
|
|
* www.amd.com
|
|
*
|
|
* Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
* of this software and associated documentation files (the "Software"), to
|
|
* deal with the Software without restriction, including without limitation
|
|
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
|
|
* and/or sell copies of the Software, and to permit persons to whom the
|
|
* Software is furnished to do so, subject to the following conditions:
|
|
*
|
|
* - Redistributions of source code must retain the above copyright notice,
|
|
* this list of conditions and the following disclaimers.
|
|
* - Redistributions in binary form must reproduce the above copyright
|
|
* notice, this list of conditions and the following disclaimers in
|
|
* the documentation and/or other materials provided with the distribution.
|
|
* - Neither the names of <Name of Development Group, Name of Institution>,
|
|
* nor the names of its contributors may be used to endorse or promote
|
|
* products derived from this Software without specific prior written
|
|
* permission.
|
|
*
|
|
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
|
|
* THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
|
|
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
|
|
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
|
|
* DEALINGS WITH THE SOFTWARE.
|
|
*
|
|
*/
|
|
|
|
__kernel void trigger_s_trap(__global int* dstArray, __global const int* srcArray, const int sz) {
|
|
// Obtain the unique ID of the work-item
|
|
size_t id = get_global_id(0);
|
|
|
|
// Adding this line _just_ to avoid any compiler optimization of this kernel
|
|
dstArray[id] = srcArray[id] * srcArray[id];
|
|
|
|
// Explicitly trigger a software trap on the first thread using AMDGCN assembly
|
|
if (id == 0) {
|
|
__asm__ volatile("s_trap 1");
|
|
}
|
|
}
|
|
|
|
|
|
__kernel void trigger_memory_violation(__global int* dstArray, __global const int* srcArray,
|
|
const int sz) {
|
|
// Obtain the unique ID of the work-item
|
|
size_t id = get_global_id(0);
|
|
|
|
// Adding this line _just_ to avoid any compiler optimization of this kernel
|
|
dstArray[id] = srcArray[id] * srcArray[id];
|
|
|
|
if (id == 0) {
|
|
// Point to a garbage memory location
|
|
int* invalidPtr = (int*)0xdeadbeef;
|
|
|
|
// Try to read from and also write to the garbage memory location to trigger a memory violation
|
|
int invalidData = *invalidPtr;
|
|
*invalidPtr = 42;
|
|
}
|
|
}
|